/// <reference types="node" />
import { Beet, SupportedTypeDefinition } from './types';
/**
 * De/Serializes a UTF8 string of a particular size.
 *
 * @param stringByteLength the number of bytes of the string
 *
 * @category beet/collection
 */
export declare const fixedSizeUtf8String: (stringByteLength: number) => Beet<string>;
/**
 * De/Serializes an array with a specific number of elements of type {@link T}.
 *
 * @template T type of elements held in the array
 *
 * @param element the De/Serializer for the element type
 * @param len the number of elements in the array
 * @param lenPrefix if `true` a 4 byte number indicating the size of the array
 * will be included before serialized array data
 *
 * @category beet/collection
 */
export declare function fixedSizeArray<T>(element: Beet<T>, len: number, lenPrefix?: boolean): Beet<T[]>;
/**
 * A De/Serializer for raw {@link Buffer}s that just copies/reads the buffer bytes
 * to/from the provided buffer.
 *
 * @param bytes the byte size of the buffer to de/serialize
 * @category beet/collection
 */
export declare function fixedSizeBuffer(bytes: number): Beet<Buffer>;
/**
 * A De/Serializer for {@link Uint8Array}s that just copies/reads the array bytes
 * to/from the provided buffer.
 *
 * @category beet/collection
 */
export declare function fixedSizeUint8Array(len: number): Beet<Uint8Array>;
/**
 * @category TypeDefinition
 */
export declare type CollectionsExports = keyof typeof import('./collections');
/**
 * @category TypeDefinition
 */
export declare type CollectionsTypeMapKey = 'string' | 'Array' | 'Buffer' | 'Uint8Array';
/**
 * @category TypeDefinition
 */
export declare type CollectionsTypeMap = Record<CollectionsTypeMapKey, SupportedTypeDefinition & {
    beet: CollectionsExports;
}>;
/**
 * Maps collections beet exports to metadata which describes in which package it
 * is defined as well as which TypeScript type is used to represent the
 * deserialized value in JavaScript.
 *
 * @category TypeDefinition
 */
export declare const collectionsTypeMap: CollectionsTypeMap;
